/* 
winDSK6_def.h
Michael G. Morrow, 2001-2005
general definitions to support winDSK host-DSP interface
*/

#ifndef WINDSK6_DEF_H_INCLUDED
#define WINDSK6_DEF_H_INCLUDED

#include "windsk6_enums.h"

/* TLC320AD535 Settings Flags */
#define SecCommWrite                1
#define SecCommRead                 2  
#define SecCommComplete             0  
         
#define PRI_COMM                    0
#define SEC_COMM_PENDING            1
#define SEC_COMM_REQD               2                             
#define MAX_ADC                     (32767) // ADC range (16-bits)
#define MIN_ADC                     (-32768)

/* Timer1 Control Flags */        
#define TIMER1_CLOCK_REQ            1
#define TIMER1_CLOCK_SET            2
#define TIMER0_CLOCK_REQ            0x81
#define TIMER0_CLOCK_SET            0x82
#define EXTERNAL_CLOCK              0 /* Fs =  48 khz */
#define TIMER1_MIN_DIVIDER          1 /* Fs = ~73 khz */
#define TIMER1_MAX_DIVIDER          18 /* Fs = ~ 4 kHz */
#define TIMER0_MIN_DIVIDER          125 /* Fs = ~150 KHz */
#define TIMER0_MAX_DIVIDER          187500 /* Fs = ~100 Hz */
#define TIMER_CLOCK                 37.5E6 /* timer internal clock */  
 
/* oscilloscope application defines */
#define SCOPE_HSize                 512
#define SCOPE_HBits                 9
#define SCOPE_VSize                 SCOPE_HSize
#define SCOPE_VBits                 SCOPE_HBits
#define SCOPE_Mid                   ((SCOPE_VSize / 2) -1)
#define SCOPE_MAX_CHANNELS          4

#define SCOPE_MODE_Time             0
#define SCOPE_MODE_Freq             1

#define SCOPE_TRIGGER_Auto          0
#define SCOPE_TRIGGER_Normal        1
#define SCOPE_TRIGGER_Immediate     2
#define SCOPE_TRIGGER_Single		3
#define SCOPE_AUTO_TRIGGER_DELAY    SCOPE_HSize /* wait up to one sweep */
  
#define SCOPE_STANDBY               0
#define SCOPE_START_ACQ             1
#define SCOPE_DATA_READY            2    

/* arbitrary waveform generator defines */
#define MAX_ARB_CHANNELS            2

/* CommDSK defines */
enum {COMMDSK_IQ_MODULATED, COMMDSK_I_MODULATED, COMMDSK_Q_MODULATED, 
	  COMMDSK_I_BASEBAND, COMMDSK_Q_BASEBAND, COMMDSK_SYMBOL_TIMING,  
	  COMMDSK_INTERFERENCE, COMMDSK_AWGN, COMMDSK_OUTPUT_OFF, COMMDSK_NUM_OUTPUTMODES};

enum {COMMDSK_2400_BAUD, COMMDSK_3000_BAUD, COMMDSK_3200_BAUD, COMMDSK_4000_BAUD, COMMDSK_4800_BAUD,
	  COMMDSK_6000_BAUD, COMMDSK_8000_BAUD, COMMDSK_9600_BAUD, COMMDSK_12000_BAUD, COMMDSK_NUM_BAUDRATES};

enum {COMMDSK_MODE_BPSK, COMMDSK_MODE_QPSK, COMMDSK_MODE_8_PSK, COMMDSK_MODE_16_PSK, COMMDSK_MODE_8_QAM, 
	  COMMDSK_MODE_16_QAM, COMMDSK_NUM_MODES};

enum {COMMDSK_PULSESHAPE_RECT, COMMDSK_PULSESHAPE_RAISEDCOSINE, COMMDSK_PULSESHAPE_ROOTRAISEDCOSINE, 
	  COMMDSK_PULSESHAPE_GAUSSIAN, COMMDSK_NUM_PULSESHAPE};

/* CommFSK defines */
enum {COMMFSK_MODE_ALT10, COMMFSK_MODE_1, COMMFSK_MODE_0, COMMFSK_MODE_PNSEQUENCE1, COMMFSK_MODE_PNSEQUENCE2, COMMFSK_MODE_PNSEQUENCE3, COMMFSK_MODE_RANDOM, COMMFSK_MODE_TEXT, COMMFSK_MODE_FILE, COMMFSK_MODE_TEXTXCVR, COMMFSK_NUM_MODES};
#define COMMFSK_TEXT_BUFFER_SIZE	32 // must be a multiple of 4
#define COMMFSK_FILTER_SIZE			128
#define COMMFSK_HEADER_LIMIT		(COMMFSK_TEXT_BUFFER_SIZE * 8) // binary in text form (1/0)


	
#endif      
